@@ -1,4 +1,4 @@
-from logilab.common.testlib import unittest_main, tag
+import unittest
 
 from cubicweb.devtools.testlib import CubicWebTC
 from cubicweb.devtools.htmlparser import XMLValidator
@@ -6,14 +6,15 @@ from cubicweb.devtools.htmlparser import XMLValidator
 
 class BoostrapTheMainTemplateTC(CubicWebTC):
 
-    @tag('index')
     def test_valid_xhtml_index(self):
-        self.view('index')
+        with self.admin_access.web_request() as req:
+            self.view('index', req=req)
 
-    @tag('error')
     def test_valid_xhtml_error(self):
         valid = self.content_type_validators.get('text/html', XMLValidator)()
-        page = valid.parse_string(self.vreg['views'].main_template(self.request(), 'error-template'))
+        with self.admin_access.web_request() as req:
+            valid.parse_string(self.vreg['views'].main_template(req, 'error-template'))
+
 
 if __name__ == '__main__':
-    unittest_main()
+    unittest.main()
